#[non_exhaustive]pub enum ErrorKind {
Tokenizer(ErrorKind),
UnexpectedEof,
ExpectedKey,
ExpectedColon,
ExpectedValue,
ExpectedCommaOrEnd(Nested),
ExpectedMapOrTuple,
TrailingData,
}Expand description
A kind of error that arose while parsing Rsn events.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Tokenizer(ErrorKind)
An error occurred tokenizing the input.
UnexpectedEof
An end-of-file error was encountered when data was still expected.
ExpectedKey
A key in a map was expected.
ExpectedColon
A : was expected.
ExpectedValue
A value was expected.
This may be encountered in both sequence (list/tuple) parsing and map parsing.
ExpectedCommaOrEnd(Nested)
Expected a , or the end-variant of the specified Nested.
ExpectedMapOrTuple
Expected either a map or a tuple.
TrailingData
Additional data was found after a complete value was parsed.